@@ -8,14 +8,14 @@ MI.test=function(feature, outcome, k1, k2){ #feature is the vector of X, outcome
 
 #' AQI Index
 #'
-#' A quantitative measure of dataset quality. The AQI Index score indicates the degree that how features are associated with the outcome in a dataset. (synonyms of "feature": "variable" "factor" "attribute") \cr
+#' A quantitative measure of dataset quality. The AQI Index score indicates the degree to which features are associated with the outcome in a dataset. (Synonyms of "feature" in this document: "independent variable," "factor," "predictor.") \cr
 #' For more information, please refer to the corresponding publication: Shi, J., Zhang, J. and Ge, Y. (2019), "An Association-Based Intrinsic Quality Index for Healthcare Dataset Ranking" <doi:10.1109/ICHI.2019.8904553>
-#' @param data data frame (features as columns and observations as rows). The outcome variable (Y) MUST be the last column. It requires at least one features and only one outcome. Both the features (Xs) and the outcome (Y) MUST be discrete (if not naturally discrete, you may try the `autoBin.binary` function in the same package).
-#' @param alpha.filter level of significance for the mutual information test of independence in step 2 (<doi:10.1109/ICHI.2019.8904553>). By default, `alpha.filter = 0.2`.
+#' @param data data frame with variables as columns and observations as rows. The data must include at least one feature (a.k.a., independent variable, predictor, factor) and only one outcome variable (Y). The outcome variable MUST BE THE LAST COLUMN. Both the features and the outcome MUST be categorical or discrete. If variables are not naturally discrete, you may preprocess them using the `autoBin.binary()` function in the same package.
+#' @param alpha.ind level of significance for the mutual information test of independence in step 2 (<doi:10.1109/ICHI.2019.8904553>). By default, `alpha.ind = 0.2`.
 #' @return The AQI Index score.
 #' @importFrom EntropyEstimation Entropy.z MI.z
 #' @examples
-#' ## Generate a toy dataset: "data"
+#' ## ---- Generate a toy dataset: "data" ----
 #' n <- 10000
 #' set.seed(1)
 #' x1 <- rbinom(n, 3, 0.5) + 0.2
@@ -29,11 +29,11 @@ MI.test=function(feature, outcome, k1, k2){ #feature is the vector of X, outcome
 #' data <- data.frame(cbind(x1, x2, x3, y))
 #' colnames(data) <- c("feature1", "feature2", "feature3", "Y")
 #'
-#' ## Calculate the AQI score of "data"
+#' ## ---- Calculate the AQI score of "data" ----
 #' AQI(data)
 #' @export
 
-AQI <- function(data, alpha.filter=0.2){ #outcome must be in the last column
+AQI <- function(data, alpha.ind=0.2){ #outcome must be in the last column
 
   data <- as.data.frame(data)
 
@@ -51,7 +51,7 @@ AQI <- function(data, alpha.filter=0.2){ #outcome must be in the last column
   for(fi in 1:(length(data)-1)){
     k1=length(table(data[fi])) #feature categories
     p_value=MI.test(data[[fi]],data[[length(data)]], k1, k2)
-    if(p_value<=alpha.filter){
+    if(p_value<=alpha.ind){
       count=count+1
       step1Index[count]=fi
     }
@@ -60,7 +60,7 @@ AQI <- function(data, alpha.filter=0.2){ #outcome must be in the last column
   indexCASMI=vector()
 
   if(count==0){
-    warning("No associated variables are found toward the outcome, thus the AQI score is zero. First, please ensure that the outcome variable is the last column. Second, please ensure that a reasonable alpha.filter is set, or use the default value.")
+    warning("No associated variables are found regarding the outcome; thus, the AQI score is zero. Please ensure that (1) the outcome variable is the last column, (2) a reasonable 'alpha.ind' is set, and (3) variables are appropriately preprocessed.")
     score=0
   } else{
     # Step 2: select features by joint SMI with Hz estimator
